make_filename: Creates a filename based on year input

Description Usage Arguments Details Value Note Examples

Description

make_filename will create a character vector filename with an assocaited year input

Usage

1

Arguments

year

The year to be in the name of the file.

Details

This takes a year input and creates a filename with this year. If the year is does not pass as.integer it will have a value of NA, and the function will throw an error after being passed to sprintf.

Value

A character vector filename

Note

This package does not depends on any extensions

Examples

1
2
3
4
## Not run: 
  make_filename(2013)

## End(Not run)

AlbertZhou991211/assignment documentation built on Aug. 3, 2020, 12:03 a.m.